@@ -1,8 +1,8 @@
+/* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $Id: diffs.h,v 1.29 2002/02/25 17:08:09 blais Exp $
- * $Date: 2002/02/25 17:08:09 $
+ * $RCSfile: diffs.h,v $
  *
- * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
+ * Copyright (C) 1999-2002  Martin Blais <blais@iro.umontreal.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -285,6 +285,10 @@ public:
       const bool                     force = false
    );
 
+   // Flags diff hunks that are equal except for whitespace and line breaks with
+   // the ignore-display flag.
+   void applyPerHunkDisplayIgnore( const int nbFiles );
+
    // Automatically merge by performing selections on file1, assuming order
    // "mine older yours", and leaving conflicts unselected.
    //
