@@ -1,8 +1,8 @@
+/* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $Id: version.h,v 1.9 2001/11/30 07:21:57 blais Exp $
- * $Date: 2001/11/30 07:21:57 $
+ * $RCSfile: version.h,v $
  *
- * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
+ * Copyright (C) 1999-2002  Martin Blais <blais@iro.umontreal.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,12 @@
 extern "C" {
 #endif
 
+extern char const xx_name[];
 extern char const xx_version[];
+extern char const xx_description[];
+extern char const xx_copyright[];
+extern char const xx_homepage[];
+extern char const xx_bugs_email[];
 
 #ifdef	__cplusplus
 }
